var folderClosed = new Image(22,22);
folderClosed.src='/style/Crystal/22/html-menu-treeview/folderClosed.gif';
var plusNode = new Image(22,22);
plusNode.src='/style/Crystal/22/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(22,22);
lastPlusNode.src='/style/Crystal/22/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(22,22);
clasicPlusNode.src='/style/Crystal/22/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(22,22);
clasicLastPlusNode.src='/style/Crystal/22/html-menu-treeview/clasicLastPlusNode.gif';
var folderGray = new Image(22,22);
folderGray.src='/style/Crystal/22/html-menu-treeview/folderGray.gif';
var folderGreen = new Image(22,22);
folderGreen.src='/style/Crystal/22/html-menu-treeview/folderGreen.gif';
var folderViolet = new Image(22,22);
folderViolet.src='/style/Crystal/22/html-menu-treeview/folderViolet.gif';
var folderYellowClosed = new Image(22,22);
folderYellowClosed.src='/style/Crystal/22/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed = new Image(22,22);
folderOrangeClosed.src='/style/Crystal/22/html-menu-treeview/folderOrangeClosed.gif';
var folderPrintClosed = new Image(22,22);
folderPrintClosed.src='/style/Crystal/22/html-menu-treeview/folderPrintClosed.gif';
